/**
    @file main.h

    Copyright (c) 2004-2006 Nokia Corporation. All rights reserved.
	
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA
*/


#ifndef _MAIN_H
#define _MAIN_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <locale.h>             /* For setlocale */

#include <sys/types.h>          /* Three includes for open(2). My BSD manual says */
#include <sys/stat.h>           /* to include only <sys/file.h>. I wonder if this */
#include <fcntl.h>              /* will break any systems. */

#include <sys/types.h>          /* For getpid(2) */

#include <conic.h>

#include <unistd.h>             /* For gethostname(), readlink(2) and symlink(2) */
#include <string.h>
#include <errno.h>
#include <string.h>
#include <stdlib.h>
#include <signal.h>
#include "conf.h"
#include "update.h"
#include "metadata.h"
#include "state_save.h"
#include "ui_feed_directory.h"

void save_application_data();

#endif
